% Direct integration and conversion of equations to state-space model
% -------------------------------------------------------------------
% 
% Linearni diferencialni rovnice 2. radu -> 1. radu (stavovy popis)
% Vychazi z prikladu pro male kmity poddajne souststavy s dvema telesy

clear all
close all
format compact

%%

% Reseni primou integraci (priklad 2 hmoty)
% -----------------------------------------

% Parametry jsou predavany prostrednictvim 
% globalnich promennych
global M0 om k1 k2 I1 I2

% Zadane hodnoty
I1=0.17;
I2=0.38;
k1=2.61e5;
k2=1.68e5;
M0=5; om=1300; %#ok
% pocatecni podminky
fi0=[0.001;
     0.003];
fi0dot=[0;
        0];
% Matice hmotnosti
M=[I1  0;
    0 I2];
% Matice tuhosti
K=[ k1   -k1;
   -k1 k1+k2];

% Vlastni tvary a frekvence
[V,OM] = eig(K,M);
OM1 = sqrt(OM(1,1));
disp(['OM1 = ' num2str(OM1)])
OM2 = sqrt(OM(2,2));
disp(['OM2 = ' num2str(OM2)])

% nastaveni delky experimentu (s)
tstart=0;
tkonec=0.04;

% nastaveni maximalni velikosti kroku pri integraci
options=odeset('MaxStep',0.0001);

[t,z]=ode45(@zdot_eq,tstart:0.0001:tkonec,[fi0dot(1),fi0dot(2),fi0(1),fi0(2)],options);
 
% Vykresleni
figure(1);
plot(t,z(:,3),'b',t,z(:,4),'r')
title('Celkove reseni pro zadane obecne pocatecni podminky');
xlabel('cas [s]'), ylabel('vychylka [rad]');
legend('y1(t)','y2(t)');

%%

% Stavovy popis a prima integrace
% -------------------------------

% Parametry jsou predavany prostrednictvim 
% globalnich promennych
global M0 om As Bs Cs Ds %#ok

% Zadane hodnoty
I1=0.17;
I2=0.38;
k1=2.61e5;
k2=1.68e5;
M0=5; om=1300; %#ok
% pocatecni podminky
fi0=[0.001;
     0.003];
fi0dot=[0;
        0];
% Matice hmotnosti
M=[I1  0;
    0 I2];
% Matice tuhosti
K=[ k1   -k1;
   -k1 k1+k2];

As = [zeros(2,2) -M\K; 
     eye(2,2) zeros(2,2)];
Bs = [M\([1 0]'); zeros(2,1)];
Cs = [zeros(2,2), eye(2,2)];
Ds = zeros(2,1);

% Vlastni cisla systemu
% 2 pary komplexne sdruzenych vl. cisel, odpovidaji vlastnim kmitoctum
eig(As)

% Prevod do stavove reprezentace
sys = ss(As,Bs,Cs,Ds);
% Zobrazeni bodeho diagram
figure(2);
bode(sys);

% nastaveni delky experimentu (s)
tstart=0;
tkonec=0.04;

% nastaveni maximalni velikosti kroku pri integraci
options=odeset('MaxStep',0.0001);

[t,z]=ode45(@zdot_sys,tstart:0.0001:tkonec,[fi0dot(1),fi0dot(2),fi0(1),fi0(2)],options);
 
% Vykresleni
figure(3);
plot(t,z(:,3),'b',t,z(:,4),'r')
title('Celkove reseni pro zadane obecne pocatecni podminky');
xlabel('cas [s]'), ylabel('vychylka [rad]');
legend('y1(t)','y2(t)');

